Enum flexi_logger::FlexiLoggerError
[−]
[src]
pub enum FlexiLoggerError {
BadDirectory,
Io(Error),
Log(SetLoggerError),
}Describes errors in the initialization of flexi_logger.
Variants
BadDirectoryLog file cannot be written because the specified path is not a directory.
Io(Error)Log cannot be written because the configured output directory is not accessible.
Log(SetLoggerError)Logger initialization failed.